@@ -1,8 +1,8 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_productionsite_type {
+wl.Descriptions():new_productionsite_type {
    name = "atlanteans_ferry_yard",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("atlanteans_building", "Ferry Yard"),
@@ -24,10 +24,19 @@ descriptions:new_productionsite_type {
    },
 
    -- TODO(Nordfriese): Make animations
+   animation_directory = dirname,
    animations = {
       idle = {
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 53, 66 },
+         hotspot = { 56, 72 },
+      }
+   },
+
+   spritesheets = {
+      build= {
+         frames = 5,
+         columns = 5,
+         rows = 1,
+         hotspot = { 56, 72 },
       }
    },
 
@@ -45,12 +54,12 @@ descriptions:new_productionsite_type {
    programs = {
       main = {
          -- TRANSLATORS: Completed/Skipped/Did not start working because ...
-         descname = _"working",
+         descname = _("working"),
          actions = {
             "sleep=duration:20s",
-            "callworker=buildferry_1",
+            "return=skipped unless fleet needs ferry",
             "consume=log:2 spidercloth",
-            "callworker=buildferry_2"
+            "callworker=buildferry",
          }
       },
    },
