@@ -1,8 +1,8 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_productionsite_type {
+wl.Descriptions():new_productionsite_type {
    name = "empire_sawmill",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("empire_building", "Sawmill"),
@@ -19,14 +19,20 @@ descriptions:new_productionsite_type {
       granite = 1
    },
 
-   animations = {
+   animation_directory = dirname,
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 54, 70 },
+         frames = 1,
+         columns = 1,
+         rows = 1,
+         hotspot = { 48, 62 },
       },
       working = {
-         pictures = path.list_files(dirname .. "idle_??.png"), -- TODO(GunChleoc): No animation yet.
-         hotspot = { 54, 70 },
+         basename = "idle", -- TODO(GunChleoc): No animation yet.
+         frames = 1,
+         columns = 1,
+         rows = 1,
+         hotspot = { 48, 62 },
       },
    },
 
@@ -47,13 +53,13 @@ descriptions:new_productionsite_type {
    programs = {
       main = {
          -- TRANSLATORS: Completed/Skipped/Did not start sawing logs because ...
-         descname = _"sawing logs",
+         descname = _("sawing logs"),
          actions = {
             "return=skipped unless economy needs planks",
             "consume=log:2",
-            "sleep=duration:16s500ms", -- Much faster than barbarians' wood hardener
+            "sleep=duration:16s500ms", -- Much faster than Barbarians' wood hardener
             "playsound=sound/sawmill/sawmill priority:40% allow_multiple",
-            "animate=working duration:20s", -- Much faster than barbarians' wood hardener
+            "animate=working duration:20s", -- Much faster than Barbarians' wood hardener
             "produce=planks"
          }
       },
