@@ -1,11 +1,12 @@
 push_textdomain("tribes")
 
-dirname = path.dirname (__file__)
+local dirname = path.dirname (__file__)
 
-descriptions:new_productionsite_type {
+wl.Descriptions():new_productionsite_type {
    name = "frisians_scouts_house",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext ("frisians_building", "Scout’s House"),
+   animation_directory = dirname,
    icon = dirname .. "menu.png",
    size = "small",
 
@@ -22,8 +23,6 @@ descriptions:new_productionsite_type {
 
    spritesheets = {
       idle = {
-         directory = dirname,
-         basename = "idle",
          hotspot = {40, 66},
          frames = 10,
          columns = 5,
@@ -33,8 +32,6 @@ descriptions:new_productionsite_type {
    },
    animations = {
       unoccupied = {
-         directory = dirname,
-         basename = "unoccupied",
          hotspot = {40, 60}
       }
    },
@@ -52,15 +49,19 @@ descriptions:new_productionsite_type {
    programs = {
       main = {
          -- TRANSLATORS: Completed/Skipped/Did not start scouting because ...
-         descname = _"scouting",
+         descname = _("scouting"),
          actions = {
+            -- time of worker: 82.2-214.8 sec
+            -- min. time total: 30 + 82.2 = 112.2 sec
+            -- max. time total: 30 + 214.8 = 244.8 sec
+            -- avg. time total: (112.2 + 244.8) / 2 = 178.5 sec
             "consume=ration",
             "sleep=duration:30s",
             "callworker=scout"
          }
       },
       targeted_scouting = {
-         descname = _"scouting",
+         descname = _("scouting"),
          actions = {
             "consume=ration",
             "callworker=targeted_scouting"
