@@ -1,8 +1,8 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_warehouse_type {
+wl.Descriptions():new_warehouse_type {
    name = "barbarians_port",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("barbarians_building", "Port"),
@@ -29,16 +29,21 @@ descriptions:new_warehouse_type {
       gold = 1
    },
 
-   animations = {
+   animation_directory = dirname,
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 67, 80 },
-         fps = 10
+         fps = 10,
+         frames = 20,
+         rows = 5,
+         columns = 4,
+         hotspot = { 66, 80 }
       },
       build = {
-         pictures = path.list_files(dirname .. "build_??.png"),
-         hotspot = { 67, 80 },
-      }
+         frames = 4,
+         rows = 2,
+         columns = 2,
+         hotspot = { 59, 77 }
+      },
    },
 
    aihints = {
@@ -47,6 +52,7 @@ descriptions:new_warehouse_type {
 
    conquers = 5,
    heal_per_second = 170,
+   max_garrison = 20,
 }
 
 pop_textdomain()
